# CGA4233DE

This is a python library to interact with the CGA4233DE router, as provided by Vodafone Germany.

## References

- [tiberiucorbu's writeup on authenticating with CGA4233DE](https://gist.github.com/tiberiucorbu/a51c81b82b5196ac002c52ac6f39987f)
